==> kubernetes-model-gatewayapi-6.3.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPRouteRuleFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPRouteRuleFluent<A extends HTTPRouteRuleFluent<A>> extends Fluent<A>{
  public A addToBackendRefs(Integer index,HTTPBackendRef item);
  public A setToBackendRefs(Integer index,HTTPBackendRef item);
  public A addToBackendRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPBackendRef... items);
  public A addAllToBackendRefs(Collection<HTTPBackendRef> items);
  public A removeFromBackendRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPBackendRef... items);
  public A removeAllFromBackendRefs(Collection<HTTPBackendRef> items);
  public A removeMatchingFromBackendRefs(Predicate<HTTPBackendRefBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildBackendRefs instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPBackendRef> getBackendRefs();
  public List<HTTPBackendRef> buildBackendRefs();
  public HTTPBackendRef buildBackendRef(Integer index);
  public HTTPBackendRef buildFirstBackendRef();
  public HTTPBackendRef buildLastBackendRef();
  public HTTPBackendRef buildMatchingBackendRef(Predicate<HTTPBackendRefBuilder> predicate);
  public Boolean hasMatchingBackendRef(Predicate<HTTPBackendRefBuilder> predicate);
  public A withBackendRefs(List<HTTPBackendRef> backendRefs);
  public A withBackendRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPBackendRef... backendRefs);
  public Boolean hasBackendRefs();
  public HTTPRouteRuleFluent.BackendRefsNested<A> addNewBackendRef();
  public HTTPRouteRuleFluent.BackendRefsNested<A> addNewBackendRefLike(HTTPBackendRef item);
  public HTTPRouteRuleFluent.BackendRefsNested<A> setNewBackendRefLike(Integer index,HTTPBackendRef item);
  public HTTPRouteRuleFluent.BackendRefsNested<A> editBackendRef(Integer index);
  public HTTPRouteRuleFluent.BackendRefsNested<A> editFirstBackendRef();
  public HTTPRouteRuleFluent.BackendRefsNested<A> editLastBackendRef();
  public HTTPRouteRuleFluent.BackendRefsNested<A> editMatchingBackendRef(Predicate<HTTPBackendRefBuilder> predicate);
  public A addToFilters(Integer index,HTTPRouteFilter item);
  public A setToFilters(Integer index,HTTPRouteFilter item);
  public A addToFilters(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteFilter... items);
  public A addAllToFilters(Collection<HTTPRouteFilter> items);
  public A removeFromFilters(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteFilter... items);
  public A removeAllFromFilters(Collection<HTTPRouteFilter> items);
  public A removeMatchingFromFilters(Predicate<HTTPRouteFilterBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildFilters instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPRouteFilter> getFilters();
  public List<HTTPRouteFilter> buildFilters();
  public HTTPRouteFilter buildFilter(Integer index);
  public HTTPRouteFilter buildFirstFilter();
  public HTTPRouteFilter buildLastFilter();
  public HTTPRouteFilter buildMatchingFilter(Predicate<HTTPRouteFilterBuilder> predicate);
  public Boolean hasMatchingFilter(Predicate<HTTPRouteFilterBuilder> predicate);
  public A withFilters(List<HTTPRouteFilter> filters);
  public A withFilters(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteFilter... filters);
  public Boolean hasFilters();
  public HTTPRouteRuleFluent.FiltersNested<A> addNewFilter();
  public HTTPRouteRuleFluent.FiltersNested<A> addNewFilterLike(HTTPRouteFilter item);
  public HTTPRouteRuleFluent.FiltersNested<A> setNewFilterLike(Integer index,HTTPRouteFilter item);
  public HTTPRouteRuleFluent.FiltersNested<A> editFilter(Integer index);
  public HTTPRouteRuleFluent.FiltersNested<A> editFirstFilter();
  public HTTPRouteRuleFluent.FiltersNested<A> editLastFilter();
  public HTTPRouteRuleFluent.FiltersNested<A> editMatchingFilter(Predicate<HTTPRouteFilterBuilder> predicate);
  public A addToMatches(Integer index,HTTPRouteMatch item);
  public A setToMatches(Integer index,HTTPRouteMatch item);
  public A addToMatches(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteMatch... items);
  public A addAllToMatches(Collection<HTTPRouteMatch> items);
  public A removeFromMatches(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteMatch... items);
  public A removeAllFromMatches(Collection<HTTPRouteMatch> items);
  public A removeMatchingFromMatches(Predicate<HTTPRouteMatchBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildMatches instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPRouteMatch> getMatches();
  public List<HTTPRouteMatch> buildMatches();
  public HTTPRouteMatch buildMatch(Integer index);
  public HTTPRouteMatch buildFirstMatch();
  public HTTPRouteMatch buildLastMatch();
  public HTTPRouteMatch buildMatchingMatch(Predicate<HTTPRouteMatchBuilder> predicate);
  public Boolean hasMatchingMatch(Predicate<HTTPRouteMatchBuilder> predicate);
  public A withMatches(List<HTTPRouteMatch> matches);
  public A withMatches(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteMatch... matches);
  public Boolean hasMatches();
  public HTTPRouteRuleFluent.MatchesNested<A> addNewMatch();
  public HTTPRouteRuleFluent.MatchesNested<A> addNewMatchLike(HTTPRouteMatch item);
  public HTTPRouteRuleFluent.MatchesNested<A> setNewMatchLike(Integer index,HTTPRouteMatch item);
  public HTTPRouteRuleFluent.MatchesNested<A> editMatch(Integer index);
  public HTTPRouteRuleFluent.MatchesNested<A> editFirstMatch();
  public HTTPRouteRuleFluent.MatchesNested<A> editLastMatch();
  public HTTPRouteRuleFluent.MatchesNested<A> editMatchingMatch(Predicate<HTTPRouteMatchBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface BackendRefsNested<N> extends Nested<N>,HTTPBackendRefFluent<HTTPRouteRuleFluent.BackendRefsNested<N>>{
    public N and();
    public N endBackendRef();
    
  }
  public interface FiltersNested<N> extends Nested<N>,HTTPRouteFilterFluent<HTTPRouteRuleFluent.FiltersNested<N>>{
    public N and();
    public N endFilter();
    
  }
  public interface MatchesNested<N> extends Nested<N>,HTTPRouteMatchFluent<HTTPRouteRuleFluent.MatchesNested<N>>{
    public N and();
    public N endMatch();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPRouteRuleFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPRouteRuleFluent<A extends HTTPRouteRuleFluent<A>> extends Fluent<A>{
  public A addToBackendRefs(int index,HTTPBackendRef item);
  public A setToBackendRefs(int index,HTTPBackendRef item);
  public A addToBackendRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPBackendRef... items);
  public A addAllToBackendRefs(Collection<HTTPBackendRef> items);
  public A removeFromBackendRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPBackendRef... items);
  public A removeAllFromBackendRefs(Collection<HTTPBackendRef> items);
  public A removeMatchingFromBackendRefs(Predicate<HTTPBackendRefBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildBackendRefs instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPBackendRef> getBackendRefs();
  public List<HTTPBackendRef> buildBackendRefs();
  public HTTPBackendRef buildBackendRef(int index);
  public HTTPBackendRef buildFirstBackendRef();
  public HTTPBackendRef buildLastBackendRef();
  public HTTPBackendRef buildMatchingBackendRef(Predicate<HTTPBackendRefBuilder> predicate);
  public Boolean hasMatchingBackendRef(Predicate<HTTPBackendRefBuilder> predicate);
  public A withBackendRefs(List<HTTPBackendRef> backendRefs);
  public A withBackendRefs(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPBackendRef... backendRefs);
  public Boolean hasBackendRefs();
  public HTTPRouteRuleFluent.BackendRefsNested<A> addNewBackendRef();
  public HTTPRouteRuleFluent.BackendRefsNested<A> addNewBackendRefLike(HTTPBackendRef item);
  public HTTPRouteRuleFluent.BackendRefsNested<A> setNewBackendRefLike(int index,HTTPBackendRef item);
  public HTTPRouteRuleFluent.BackendRefsNested<A> editBackendRef(int index);
  public HTTPRouteRuleFluent.BackendRefsNested<A> editFirstBackendRef();
  public HTTPRouteRuleFluent.BackendRefsNested<A> editLastBackendRef();
  public HTTPRouteRuleFluent.BackendRefsNested<A> editMatchingBackendRef(Predicate<HTTPBackendRefBuilder> predicate);
  public A addToFilters(int index,HTTPRouteFilter item);
  public A setToFilters(int index,HTTPRouteFilter item);
  public A addToFilters(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteFilter... items);
  public A addAllToFilters(Collection<HTTPRouteFilter> items);
  public A removeFromFilters(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteFilter... items);
  public A removeAllFromFilters(Collection<HTTPRouteFilter> items);
  public A removeMatchingFromFilters(Predicate<HTTPRouteFilterBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildFilters instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPRouteFilter> getFilters();
  public List<HTTPRouteFilter> buildFilters();
  public HTTPRouteFilter buildFilter(int index);
  public HTTPRouteFilter buildFirstFilter();
  public HTTPRouteFilter buildLastFilter();
  public HTTPRouteFilter buildMatchingFilter(Predicate<HTTPRouteFilterBuilder> predicate);
  public Boolean hasMatchingFilter(Predicate<HTTPRouteFilterBuilder> predicate);
  public A withFilters(List<HTTPRouteFilter> filters);
  public A withFilters(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteFilter... filters);
  public Boolean hasFilters();
  public HTTPRouteRuleFluent.FiltersNested<A> addNewFilter();
  public HTTPRouteRuleFluent.FiltersNested<A> addNewFilterLike(HTTPRouteFilter item);
  public HTTPRouteRuleFluent.FiltersNested<A> setNewFilterLike(int index,HTTPRouteFilter item);
  public HTTPRouteRuleFluent.FiltersNested<A> editFilter(int index);
  public HTTPRouteRuleFluent.FiltersNested<A> editFirstFilter();
  public HTTPRouteRuleFluent.FiltersNested<A> editLastFilter();
  public HTTPRouteRuleFluent.FiltersNested<A> editMatchingFilter(Predicate<HTTPRouteFilterBuilder> predicate);
  public A addToMatches(int index,HTTPRouteMatch item);
  public A setToMatches(int index,HTTPRouteMatch item);
  public A addToMatches(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteMatch... items);
  public A addAllToMatches(Collection<HTTPRouteMatch> items);
  public A removeFromMatches(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteMatch... items);
  public A removeAllFromMatches(Collection<HTTPRouteMatch> items);
  public A removeMatchingFromMatches(Predicate<HTTPRouteMatchBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildMatches instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HTTPRouteMatch> getMatches();
  public List<HTTPRouteMatch> buildMatches();
  public HTTPRouteMatch buildMatch(int index);
  public HTTPRouteMatch buildFirstMatch();
  public HTTPRouteMatch buildLastMatch();
  public HTTPRouteMatch buildMatchingMatch(Predicate<HTTPRouteMatchBuilder> predicate);
  public Boolean hasMatchingMatch(Predicate<HTTPRouteMatchBuilder> predicate);
  public A withMatches(List<HTTPRouteMatch> matches);
  public A withMatches(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.HTTPRouteMatch... matches);
  public Boolean hasMatches();
  public HTTPRouteRuleFluent.MatchesNested<A> addNewMatch();
  public HTTPRouteRuleFluent.MatchesNested<A> addNewMatchLike(HTTPRouteMatch item);
  public HTTPRouteRuleFluent.MatchesNested<A> setNewMatchLike(int index,HTTPRouteMatch item);
  public HTTPRouteRuleFluent.MatchesNested<A> editMatch(int index);
  public HTTPRouteRuleFluent.MatchesNested<A> editFirstMatch();
  public HTTPRouteRuleFluent.MatchesNested<A> editLastMatch();
  public HTTPRouteRuleFluent.MatchesNested<A> editMatchingMatch(Predicate<HTTPRouteMatchBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface BackendRefsNested<N> extends Nested<N>,HTTPBackendRefFluent<HTTPRouteRuleFluent.BackendRefsNested<N>>{
    public N and();
    public N endBackendRef();
    
  }
  public interface FiltersNested<N> extends Nested<N>,HTTPRouteFilterFluent<HTTPRouteRuleFluent.FiltersNested<N>>{
    public N and();
    public N endFilter();
    
  }
  public interface MatchesNested<N> extends Nested<N>,HTTPRouteMatchFluent<HTTPRouteRuleFluent.MatchesNested<N>>{
    public N and();
    public N endMatch();
    
  }
  
}
